@@ -17,31 +17,62 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Fetch astronomical data from SIMBAD 4.';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
     return +{
+	'Data::Dumper'	=> 0,
 	'Test::More'	=> 0.96,	# For subtest().
+	lib		=> 0,
     };
 }
 
+sub configure_requires {
+    return +{
+	'Config'	=> 0,
+	'Getopt::Std'	=> 0,
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Astro-SIMBAD-Client';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
-	no_index => {
-	    directory => [ qw{ inc t xt } ],
-	},
-	resources => {
+	dynamic_config	=> 1,
+	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues',
-#                mailto  => 'wyant@cpan.org',
-            },
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client',
+		# web	=> 'https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
@@ -53,14 +84,62 @@ sub meta_merge {
     };
 }
 
+sub module_name {
+    return 'Astro::SIMBAD::Client';
+}
+
+sub no_index {
+    return +{
+	directory => [ qw{ eg inc t xt } ],
+    };
+}
+
 sub provides {
-    -d 'lib'
-	or return;
+    my $provides;
     local $@ = undef;
-    my $provides = eval {
+
+    eval {
+	require CPAN::Meta;
+	require ExtUtils::Manifest;
 	require Module::Metadata;
-	Module::Metadata->provides( version => 2, dir => 'lib' );
+
+	my $manifest;
+	{
+	    local $SIG{__WARN__} = sub {};
+	    $manifest = ExtUtils::Manifest::maniread();
+	}
+	keys %{ $manifest || {} }
+	    or return;
+
+	# Skeleton so we can use should_index_file() and
+	# should_index_package().
+	my $meta = CPAN::Meta->new( {
+		name	=> 'Euler',
+		version	=> 2.71828,
+		no_index	=> no_index(),
+	    },
+	);
+
+	# The Module::Metadata docs say not to use
+	# package_versions_from_directory() directly, but the 'files =>'
+	# version of provides() is broken, and has been known to be so
+	# since 2014, so it's not getting fixed any time soon. So:
+
+	foreach my $fn ( sort keys %{ $manifest } ) {
+	    $fn =~ m/ [.] pm \z /smx
+		or next;
+	    my $pvd = Module::Metadata->package_versions_from_directory(
+		undef, [ $fn ] );
+	    foreach my $pkg ( keys %{ $pvd } ) {
+		$meta->should_index_package( $pkg )
+		    and $meta->should_index_file( $pvd->{$pkg}{file} )
+		    and $provides->{$pkg} = $pvd->{$pkg};
+	    }
+	}
+
+	1;
     } or return;
+
     return ( provides => $provides );
 }
 
@@ -69,6 +148,7 @@ sub requires {
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
+	'Carp'			=> 0,
 	'HTTP::Request::Common'	=> 0,
 	'LWP::Protocol'	=> 0,	# Comes with LWP, but ...
 	'LWP::UserAgent' => 0,
@@ -76,6 +156,9 @@ sub requires {
 	'Scalar::Util' => 1.01,	# Not in Perl 5.6
 	'URI::Escape' => 0,
 	'XML::DoubleEncodedEntities' => 1.0,
+	constant	=> 0,
+	strict		=> 0,
+	warnings	=> 0,
 	@extra,
     };
 }
@@ -84,6 +167,15 @@ sub requires_perl {
     return 5.008;	# SOAP::Lite dependencies
 }
 
+sub script_files {
+    return [
+	'script/simbadc',
+    ];
+}
+
+sub version_from {
+    return 'lib/Astro/SIMBAD/Client.pm';
+}
 
 1;
 
@@ -118,6 +210,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -128,6 +233,20 @@ modules required to build the C<Astro::SIMBAD::Client> package, suitable
 for use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -139,6 +258,10 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -146,10 +269,21 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
 
 Any arguments will be appended to the generated array.
 
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -178,11 +312,20 @@ true, configuration-specific modules may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -191,11 +334,11 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SIMBAD-Client>,
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues>, or in
 electronic mail to the author.
 
 =head1 AUTHOR
